References and further reading
==============================


References
----------

.. bibliography:: references.bib
	:cited:
	:style: unsrt
	:labelprefix: R



Further reading
---------------

.. todo:: The following references are not cited anywhere within the documentation. Looking through the list, some should probably be cited somewhere, or deleted.

For more details and further information on quantum machine learning and quantum computation, please see the following:

.. bibliography:: references.bib
	:notcited:
	:style: unsrt
	:labelprefix: FR
